@@ -1,9 +1,10 @@
 package resources
 
 import (
-	"github.com/intel/sriov-network-device-plugin/pkg/utils"
 	"reflect"
 
+	"github.com/intel/sriov-network-device-plugin/pkg/utils"
+
 	pluginapi "k8s.io/kubernetes/pkg/kubelet/apis/deviceplugin/v1beta1"
 
 	"github.com/intel/sriov-network-device-plugin/pkg/types"
@@ -51,38 +52,42 @@ var _ = Describe("Factory", func() {
 				codes := []string{"1111", "1111", "1234", "4321"}
 				drivers := []string{"vfio-pci", "i40evf", "igb_uio", "igb_uio"}
 				pfNames := []string{"enp2s0f2", "ens0", "eth0", "net2"}
+				pciAddr := []string{"0000:03:02.0", "0000:03:02.1", "0000:03:02.2", "0000:03:02.3"}
 				linkTypes := []string{"ether", "infiniband", "other", "other2"}
+				ddpProfiles := []string{"GTP", "PPPoE", "GTP", "PPPoE"}
 				for i := range devs {
 					d := &mocks.PciNetDevice{}
 					d.On("GetVendor").Return(vendors[i]).
 						On("GetDeviceCode").Return(codes[i]).
 						On("GetDriver").Return(drivers[i]).
 						On("GetPFName").Return(pfNames[i]).
-						On("GetPciAddr").Return("fake").
+						On("GetPciAddr").Return(pciAddr[i]).
 						On("GetAPIDevice").Return(&pluginapi.Device{}).
-						On("GetLinkType").Return(linkTypes[i])
+						On("GetLinkType").Return(linkTypes[i]).
+						On("GetDDPProfiles").Return(ddpProfiles[i])
 					devs[i] = d
 				}
 
 				c := types.ResourceConfig{
 					ResourceName: "fake",
 					Selectors: struct {
-						Vendors   []string `json:"vendors,omitempty"`
-						Devices   []string `json:"devices,omitempty"`
-						Drivers   []string `json:"drivers,omitempty"`
-						PfNames   []string `json:"pfNames,omitempty"`
-						LinkTypes []string `json:"linkTypes,omitempty"`
+						Vendors     []string `json:"vendors,omitempty"`
+						Devices     []string `json:"devices,omitempty"`
+						Drivers     []string `json:"drivers,omitempty"`
+						PfNames     []string `json:"pfNames,omitempty"`
+						LinkTypes   []string `json:"linkTypes,omitempty"`
+						DDPProfiles []string `json:"ddpProfiles,omitempty"`
 					}{[]string{"8086"}, []string{"1111"}, []string{"vfio-pci"}, []string{"enp2s0f2"},
-						[]string{"ether"}},
+						[]string{"ether"}, []string{"GTP"}},
 				}
 
 				rp, err = f.GetResourcePool(&c, devs)
 			})
 			It("should return valid resource pool", func() {
 				Expect(rp).NotTo(BeNil())
-				Expect(rp.(*resourcePool).devices).To(HaveLen(1))
-				Expect(rp.(*resourcePool).devices).To(HaveKey("fake"))
-				Expect(rp.(*resourcePool).devicePool).To(HaveKeyWithValue("fake", devs[0]))
+				Expect(rp.(*resourcePool).devices).To(HaveLen(4))
+				Expect(rp.(*resourcePool).devices).To(HaveKey("0000:03:02.0"))
+				Expect(rp.(*resourcePool).devicePool).To(HaveKeyWithValue("0000:03:02.0", devs[0]))
 			})
 			It("should not fail", func() {
 				Expect(err).NotTo(HaveOccurred())
@@ -101,20 +106,4 @@ var _ = Describe("Factory", func() {
 			})
 		})
 	})
-	DescribeTable("GetSelector with various inputs", func(attr string, values []string, expSel types.DeviceSelector) {
-		f := NewResourceFactory("fake", "fake", true)
-		s, _ := f.GetSelector(attr, values)
-
-		if reflect.TypeOf(expSel) == nil {
-			Expect(reflect.TypeOf(s)).To(BeNil())
-		} else {
-			Expect(reflect.TypeOf(s)).To(Equal(reflect.TypeOf(expSel)))
-		}
-	},
-		Entry("vendors selector", "vendors", []string{"15b3"}, &vendorSelector{vendors: []string{""}}),
-		Entry("devices selector", "devices", []string{"1014"}, &deviceSelector{devices: []string{""}}),
-		Entry("drivers selector", "drivers", []string{"mlx5_core"}, &driverSelector{drivers: []string{""}}),
-		Entry("pfNames selector", "pfNames", []string{"enp2s0f0"}, &pfNameSelector{pfNames: []string{""}}),
-		Entry("linkTypes selector", "linkTypes", []string{"ether"}, &linkTypeSelector{linkTypes: []string{""}}),
-		Entry("invalid input", "dummyAttr", []string{"dummyVal"}, nil))
 })
